@@ -32,64 +32,40 @@
 import os
 import sys
 import logging
-from logging.handlers import SysLogHandler
 
-from hubzero.submit.JobHarvester import JobHarvester
+from hubzero.submit.ApplicationUtilities import ApplicationUtilities as ApplicationUtilities
+from hubzero.submit.JobHarvester         import JobHarvester
 
-LOGDIRECTORY      = os.path.join(os.sep,'var','log','submit','distributor')
-APPLICATIONLOGGER = logging.getLogger('')
+DISTRIBUTORLOGLEVEL         = "INFO"
+DISTRIBUTORSYSLOGLOCAL      = "LOCAL3"
+DISTRIBUTORSYSLOGIDENTIFIER = "SUBMITDISTRIBUTOR"
 
 CONFIGURATIONDIRECTORY       = os.path.join(os.sep,'etc','submit')
 DISTRIBUTORCONFIGURATIONFILE = 'distributor.conf'
+DAEMONSDIRECTORY             = os.path.join(os.sep,"etc","submit")
 DAEMONSCONFIGURATIONFILE     = 'daemons.conf'
+INFOSDIRECTORY               = os.path.join(os.sep,"etc","submit")
 INFOSCONFIGURATIONFILE       = 'infos.conf'
 
-def openLogger():
-   class EmptyFilter(logging.Filter):
-      """
-      This is a filter which rejects empty messages
-
-      """
-
-      def filter(self,record):
-         if record.getMessage() == "":
-            emptyRecord = True
-         else:
-            emptyRecord = False
-
-         return(not emptyRecord)
-
-   APPLICATIONLOGGER.setLevel(logging.ERROR)
-
-   logSyslogHandler = SysLogHandler(address="/dev/log",facility=SysLogHandler.LOG_LOCAL3)
-   emptyFilter = EmptyFilter()
-   logSyslogHandler.addFilter(emptyFilter)
-   logFormatter = logging.Formatter('%(asctime)s %(message)s','%s [%a %b %d %H:%M:%S %Y]')
-   logSyslogHandler.setFormatter(logFormatter)
-   APPLICATIONLOGGER.addHandler(logSyslogHandler)
-
-
-def harvester(configurationDirectory,
-              distributorConfigurationFile,daemonsConfigurationFile,infosConfigurationFile):
-   jobHarvester = JobHarvester(configurationDirectory,
-                               distributorConfigurationFile,daemonsConfigurationFile,infosConfigurationFile)
-   if jobHarvester.configure():
-      exitCode = jobHarvester.processCommandArguments()
-      if not exitCode:
-         exitCode = jobHarvester.buildJobInstances()
-         if not exitCode:
-            exitCode = jobHarvester.harvestJobInstances()
-      exitCode = jobHarvester.reportExitCondition()
-   else:
-      exitCode = 1
-
-   sys.exit(exitCode)
-
-
 if __name__ == '__main__':
-   openLogger()
+   distributorLogLevel          = os.getenv("DISTRIBUTORLOGLEVEL",DISTRIBUTORLOGLEVEL)
+   distributorSysLogLocal       = os.getenv("DISTRIBUTORSYSLOGLOCAL",DISTRIBUTORSYSLOGLOCAL)
+   distributorSysLogIdentifier  = os.getenv("DISTRIBUTORSYSLOGIDENTIFIER",DISTRIBUTORSYSLOGIDENTIFIER)
+   configurationDirectory       = os.getenv("CONFIGURATIONDIRECTORY",CONFIGURATIONDIRECTORY)
+   distributorConfigurationFile = os.getenv("DISTRIBUTORCONFIGURATIONFILE",DISTRIBUTORCONFIGURATIONFILE)
+   daemonsDirectory             = os.getenv("DAEMONSDIRECTORY",DAEMONSDIRECTORY)
+   daemonsConfigurationFile     = os.getenv("DAEMONSCONFIGURATIONFILE",DAEMONSCONFIGURATIONFILE)
+   infosDirectory               = os.getenv("INFOSDIRECTORY",INFOSDIRECTORY)
+   infosConfigurationFile       = os.getenv("INFOSCONFIGURATIONFILE",INFOSCONFIGURATIONFILE)
 
-   harvester(CONFIGURATIONDIRECTORY,
-             DISTRIBUTORCONFIGURATIONFILE,DAEMONSCONFIGURATIONFILE,INFOSCONFIGURATIONFILE)
+   applicationUtilities = ApplicationUtilities(DISTRIBUTORLOGLEVEL,
+                                               DISTRIBUTORSYSLOGLOCAL)
+   applicationUtilities.openSysLogLogger(distributorSysLogLocal,
+                                         distributorLogLevel,
+                                         logIdentifier=distributorSysLogIdentifier)
+
+   harvester(configurationDirectory,distributorConfigurationFile,
+             daemonsDirectory,daemonsConfigurationFile,
+             infosDirectory,infosConfigurationFile)
 
 
