@@ -60,6 +60,9 @@ class RemoteBatchSGE:
                 managerInfo,
                 nNodes,
                 ppn,
+                nGpus,
+                gpn,
+                memoryMB,
                 wallTime,
                 quotaLimit,
                 timeHistoryLogs):
@@ -76,6 +79,7 @@ class RemoteBatchSGE:
       self.appScriptName            = appScriptName
       self.environment              = environment
       self.stageFiles               = siteInfo['stageFiles']
+      self.timePaths                = siteInfo['timePaths']
       self.submissionScriptsInfo    = submissionScriptsInfo
       self.transferExecutable       = transferExecutable
       if transferExecutable:
@@ -97,6 +101,9 @@ class RemoteBatchSGE:
       self.postManagerCommands      = managerInfo['postManagerCommands']
       self.nNodes                   = nNodes
       self.ppn                      = ppn
+      self.nGpus                    = nGpus
+      self.gpn                      = gpn
+      self.memoryMB                 = memoryMB
       self.hostAttributes           = siteInfo['hostAttributes']
       self.remoteBatchQueue         = siteInfo['remoteBatchQueue']
       self.parallelEnvironment      = siteInfo['parallelEnvironment']
@@ -175,13 +182,15 @@ class RemoteBatchSGE:
          substitutions["QUOTA"]                 = "ulimit -f " + str(self.quotaLimit)
       else:
          substitutions["QUOTA"]                 = ""
+      substitutions["TIMEPATHS"]                = ' '.join(self.timePaths)
 
       template = ParameterTemplate(rawSubmissionScript)
       try:
          submissionScript = template.substitute_recur(substitutions)
       except KeyError as e:
          submissionScript = ""
-         self.logger.log(logging.ERROR,getLogMessage("Pattern substitution failed for @@%s\n" % (e.args[0])))
+         self.logger.log(logging.ERROR,getLogMessage("Pattern substitution failed for @@{%s}\n" % (e.args[0])))
+         self.logger.log(logging.ERROR,getLogMessage("in SubmissionScripts/Distributor/Batch/SGE/serial\n"))
       except TypeError:
          submissionScript = ""
          self.logger.log(logging.ERROR,getLogMessage("Submission script substitution failed:\n%s\n" % (rawSubmissionScript)))
@@ -242,13 +251,15 @@ class RemoteBatchSGE:
          substitutions["QUOTA"]                 = "ulimit -f " + str(self.quotaLimit)
       else:
          substitutions["QUOTA"]                 = ""
+      substitutions["TIMEPATHS"]                = ' '.join(self.timePaths)
 
       template = ParameterTemplate(rawSubmissionScript)
       try:
          submissionScript = template.substitute_recur(substitutions)
       except KeyError as e:
          submissionScript = ""
-         self.logger.log(logging.ERROR,getLogMessage("Pattern substitution failed for @@%s\n" % (e.args[0])))
+         self.logger.log(logging.ERROR,getLogMessage("Pattern substitution failed for @@{%s}\n" % (e.args[0])))
+         self.logger.log(logging.ERROR,getLogMessage("in SubmissionScripts/Distributor/Batch/SGE/parallel\n"))
       except TypeError:
          submissionScript = ""
          self.logger.log(logging.ERROR,getLogMessage("Submission script substitution failed:\n%s\n" % (rawSubmissionScript)))
@@ -311,7 +322,8 @@ class RemoteBatchSGE:
          submissionScript = template.substitute_recur(substitutions)
       except KeyError as e:
          submissionScript = ""
-         self.logger.log(logging.ERROR,getLogMessage("Pattern substitution failed for @@%s\n" % (e.args[0])))
+         self.logger.log(logging.ERROR,getLogMessage("Pattern substitution failed for @@{%s}\n" % (e.args[0])))
+         self.logger.log(logging.ERROR,getLogMessage("in SubmissionScripts/Distributor/Batch/SGE/mpi\n"))
       except TypeError:
          submissionScript = ""
          self.logger.log(logging.ERROR,getLogMessage("Submission script substitution failed:\n%s\n" % (rawSubmissionScript)))
