@@ -312,6 +312,7 @@ class SitesInfo:
                                                 'remoteApplicationRootDirectory':'',
                                                 'remoteScratchDirectory':'',
                                                 'remotePpn':'',
+                                                'remoteGpn':0,
                                                 'remoteManager':'',
                                                 'remoteHostAttribute':'',
                                                 'stageFiles':True,
@@ -334,6 +335,11 @@ class SitesInfo:
                                                 'maximumCores':0,
                                                 'minimumCoreWallTime':0.,
                                                 'maximumCoreWallTime':0.,
+                                                'minimumGPUs':0,
+                                                'maximumGPUs':0,
+                                                'minimumMemoryMB':0,
+                                                'maximumMemoryMB':0,
+                                                'defaultMemoryMB':0,
                                                 'pegasusTemplates':[],
                                                 'tapisSite':'',
                                                 'executionMode':'block',
@@ -543,6 +549,10 @@ class SitesInfo:
    def purgeResourceLimitedSites(self,
                                  siteNames,
                                  nCores,
+                                 ppn,
+                                 nGpus,
+                                 gpn,
+                                 memoryMB,
                                  jobWallTime):
       markedForDeletion = []
       for siteName in self.sites:
@@ -571,12 +581,42 @@ class SitesInfo:
                         elif nMemberSiteCores < 0:
                            membersMarkedForDeletion.append(member)
 
+                        try:
+                           userPpn = int(ppn)
+                        except:
+                           pass
+                        else:
+                           try:
+                              nMemberSitePpn = int(memberSite['remotePpn'])
+                           except:
+                              pass
+                           else:
+                              if userPpn > nMemberSitePpn:
+                                 membersMarkedForDeletion.append(member)
+
+                        if gpn <= 0:
+                           if nGpus < memberSite['minimumGPUs']:
+                              membersMarkedForDeletion.append(member)
+                           if nGpus > memberSite['maximumGPUs']:
+                              membersMarkedForDeletion.append(member)
+
+                        if gpn > memberSite['remoteGpn']:
+                           membersMarkedForDeletion.append(member)
+                        if gpn > 0 and memberSite['maximumGPUs'] <= 0:
+                           membersMarkedForDeletion.append(member)
+
                         if float(jobWallTime) < memberSite['minimumWallTime']:
                            membersMarkedForDeletion.append(member)
                         if memberSite['maximumWallTime'] > 0.:
                            if float(jobWallTime) > memberSite['maximumWallTime']:
                               membersMarkedForDeletion.append(member)
 
+                        if memoryMB > 0:
+                           if memoryMB < memberSite['minimumMemoryMB']:
+                              membersMarkedForDeletion.append(member)
+                           if memoryMB > memberSite['maximumMemoryMB']:
+                              membersMarkedForDeletion.append(member)
+
                         jobCoreWallTime = nMemberSiteCores * float(jobWallTime)
                         if jobCoreWallTime < memberSite['minimumCoreWallTime']:
                            membersMarkedForDeletion.append(member)
@@ -607,12 +647,42 @@ class SitesInfo:
                elif nSiteCores < 0:
                   markedForDeletion.append(siteName)
 
+               try:
+                  userPpn = int(ppn)
+               except:
+                  pass
+               else:
+                  try:
+                     nSitePpn = int(site['remotePpn'])
+                  except:
+                     pass
+                  else:
+                     if userPpn > nSitePpn:
+                        markedForDeletion.append(siteName)
+
+               if gpn <= 0:
+                  if nGpus < site['minimumGPUs']:
+                     markedForDeletion.append(siteName)
+                  if nGpus > site['maximumGPUs']:
+                     markedForDeletion.append(siteName)
+
+               if gpn > site['remoteGpn']:
+                  markedForDeletion.append(siteName)
+               if gpn > 0 and site['maximumGPUs'] <= 0:
+                  markedForDeletion.append(siteName)
+
                if float(jobWallTime) < site['minimumWallTime']:
                   markedForDeletion.append(siteName)
                if site['maximumWallTime'] > 0.:
                   if float(jobWallTime) > site['maximumWallTime']:
                      markedForDeletion.append(siteName)
 
+               if memoryMB > 0:
+                  if memoryMB < site['minimumMemoryMB']:
+                     markedForDeletion.append(siteName)
+                  if memoryMB > site['maximumMemoryMB']:
+                     markedForDeletion.append(siteName)
+
                jobCoreWallTime = nSiteCores * float(jobWallTime)
                if jobCoreWallTime < site['minimumCoreWallTime']:
                   markedForDeletion.append(siteName)
@@ -1092,6 +1162,8 @@ class SitesInfo:
       siteInfo['hostAttributes']                   = ""
       siteInfo['executableClassificationsAllowed'] = ['*']
       siteInfo['remotePpn']                        = "1"
+      siteInfo['remoteGpn']                        = 0
+      siteInfo['defaultMemoryMB']                  = 0
       siteInfo['pegasusTemplates']                 = []
       siteInfo['tapisSite']                        = ""
       siteInfo['executionMode']                    = 'block'
@@ -1151,6 +1223,8 @@ class SitesInfo:
       siteInfo['hostAttributes']                   = site['remoteHostAttribute']
       siteInfo['executableClassificationsAllowed'] = site['executableClassificationsAllowed']
       siteInfo['remotePpn']                        = site['remotePpn']
+      siteInfo['remoteGpn']                        = site['remoteGpn']
+      siteInfo['defaultMemoryMB']                  = site['defaultMemoryMB']
       siteInfo['pegasusTemplates']                 = site['pegasusTemplates']
       siteInfo['tapisSite']                        = site['tapisSite']
       siteInfo['executionMode']                    = site['executionMode']
